numina.exceptions — Numina exceptions — Numina 0.20.dev0 documentation

# `numina.exceptions` — Numina exceptions

Exceptions for the numina package.

exception `numina.exceptions.` `DetectorElapseError`

  Error in the clocking of a Detector.

exception `numina.exceptions.` `DetectorReadoutError`

  Error in the readout of a Detector.

exception `numina.exceptions.` `Error`

  Base class for exceptions in the numina package.

exception `numina.exceptions.` `NoResultFound`

  No result found in a DAL query.

`numina.exceptions.` `NoResultFoundOrig`

  alias of `numina.exceptions.NoResultFound`

exception `numina.exceptions.` `RecipeError`

  A non recoverable problem during recipe execution.

exception `numina.exceptions.` `ValidationError`

  Error during validation of Recipe inputs and outputs.